@@ -12,7 +12,7 @@ It is not quite valid because:
 =over 8
 
 =item *
-We SOA records, which Amazon would handle for us.
+We ignore SOA records, which Amazon would handle for us.
 
 =item *
 Our TXT records handling uses "T" not ":".
@@ -50,7 +50,7 @@ use overload '""' => 'stringify';
 
 Constructor, which sets the type of the object.
 
-The constructor is expexected to be passed a valid line of text which
+The constructor is expected to be passed a valid line of text which
 describes a single record, for example C<+example.example.com:1.2.3.4:200>.
 
 =cut
@@ -63,6 +63,11 @@ sub new
     my $self = {};
     bless( $self, $class );
 
+    #
+    #  Record the line we were created with.
+    #
+    $self->{ 'input' } = $line;
+
     #
     #  The record-type is the first character.
     #
@@ -199,6 +204,20 @@ sub new
 }
 
 
+=head2 input
+
+Return the text that this record was created with.
+
+=cut
+
+sub input
+{
+    my ($self) = (@_);
+
+    return ( $self->{ 'input' } );
+}
+
+
 =head2 valid
 
 Is this record valid?  Return 0 or 1 as appropriate.
@@ -347,7 +366,7 @@ Steve Kemp <steve@steve.org.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014 Steve Kemp <steve@steve.org.uk>.
+Copyright (C) 2014-2015 Steve Kemp <steve@steve.org.uk>.
 
 This code was developed for an online Git-based DNS hosting solution,
 which can be found at:
